@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2016-09-27'; # DATE
-our $VERSION = '0.64'; # VERSION
+our $DATE = '2016-09-28'; # DATE
+our $VERSION = '0.65'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -18,6 +18,7 @@ use Perinci::Access::Perl;
 use Perinci::Sub::To::CLIDocData qw(gen_cli_doc_data_from_meta);
 use Perinci::To::POD;
 use PERLANCAR::ShellQuote::Any;
+use Proc::ChildError qw(explain_child_error);
 use Scalar::Util qw(blessed);
 use Sub::Identify qw(sub_fullname);
 
@@ -339,11 +340,22 @@ sub _process_script {
                             print $fh $file->encoded_content;
                             close $fh;
                             my $cmdline = $eg->{cmdline};
-                            $cmdline =~ s/\[\[prog\]\]/shell_quote($^X, $filename)/e;
+                            $cmdline =~ s/\[\[prog\]\]/shell_quote($^X, "-Ilib", $filename)/e;
                             IPC::System::Options::system(
                                 {shell => 0, capture_stdout => \$fres},
                                 "bash", "-c", $cmdline);
-                            $self->log_debug(["res: %s", $res]);
+                            if ($?) {
+                                $self->log_fatal(["Example #%d (subcommand %s): cmdline %s: failed: %s", $eg->{_i}, $eg->{_sc_name}, $cmdline, explain_child_error()]);
+                            }
+                            if (my $max_lines = $eg->{example_spec}{'x.doc.max_result_lines'}) {
+                                my @lines = split /^/, $fres;
+                                if (@lines > $max_lines) {
+                                    my $n = int($max_lines/2);
+                                    splice @lines, $n, (@lines - $max_lines + 1), "...\n";
+                                    $fres = join("", @lines);
+                                }
+                            }
+                            $self->log_debug(["fres: %s", $fres]);
                         } else {
                             $self->log_debug(["Example #%d (subcommand %s) has src with unsupported src_plang ($eg->{srg_plang}), skipped showing result", $eg->{_i}, $eg->{_sc_name}]);
                             last SHOW_RESULT;
@@ -873,7 +885,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.64 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2016-09-27.
+This document describes version 0.65 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2016-09-28.
 
 =head1 SYNOPSIS
 
